@@ -3,14 +3,17 @@
 use strict;
 use warnings;
 
-require Module::ScanDeps::Static::VERSION;
+our $VERSION = '1.003';
+
+use lib 'lib';
 
 use Module::ScanDeps::Static;
 
 __PACKAGE__->main();
 
 sub main {
-  return Module::ScanDeps::Static->main;
-}
+
+  exit Module::ScanDeps::Static->main;
+} ## end sub main
 
 1;
